// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "display/mesh/Mesh.hpp"

namespace Dawn {
  class CapsuleMesh {
    protected:
      /**
       * Calculates a ring of vertices within a capsule.
       * 
       * @param segments Count of segments in the ring.
       * @param height Height of the ring.
       * @param radius Radius of the ring.
       * @param dr The delta radius of the ring.
       * @param y The y position of the ring.
       * @param dy The delta y position of the ring.
       * @param positions The positions vector to push the positions to.
       */
      static void calculateRing(
        const int32_t segments,
        const float_t height,
        const float_t radius,
        const float_t dr,
        const float_t y,
        const float_t dy,
        std::vector<glm::vec3> &positions
      );

    public:
      /**
       * Creates a capsule mesh.
       * 
       * @param mesh Mesh to instanciate.
       * @param radius Radius of the capsule.
       * @param height Height of the capsule.
       */
      static void create(
        Mesh &mesh,
        const float_t radius,
        const float_t height
      );
  };
}